.. _api-reference:

*************
API Reference
*************

.. currentmodule:: MCEq

Submodules
==========
.. toctree::
  :maxdepth: 1
  :glob:

  charm_models
  config
  core
  data
  geometry/index
  misc
  particlemanager
  solvers


Reference/API
=============
.. automodapi:: MCEq
    :no-inheritance-diagram:
